@@ -151,6 +151,7 @@ void PipeWireSourceItem::resetFd()
     d->m_createNextTexture = [] {
         return nullptr;
     };
+    Q_EMIT streamSizeChanged();
 }
 
 void PipeWireSourceItem::refresh()
@@ -163,11 +164,16 @@ void PipeWireSourceItem::refresh()
 
     if (d->m_nodeId == 0) {
         d->m_stream.reset(nullptr);
+        Q_EMIT streamSizeChanged();
+
         d->m_createNextTexture = [] {
             return nullptr;
         };
     } else {
         d->m_stream.reset(new PipeWireSourceStream(this));
+        Q_EMIT streamSizeChanged();
+        connect(d->m_stream.get(), &PipeWireSourceStream::streamParametersChanged, this, &PipeWireSourceItem::streamSizeChanged);
+
         d->m_stream->createStream(d->m_nodeId, d->m_fd.value_or(0));
         if (!d->m_stream->error().isEmpty()) {
             d->m_stream.reset(nullptr);
@@ -279,7 +285,7 @@ QSGNode *PipeWireSourceItem::updatePaintNode(QSGNode *node, QQuickItem::UpdatePa
         pwNode->discardCursor();
     } else {
         QSGImageNode *cursorNode = pwNode->cursorNode(window());
-        if (d->m_cursor.dirty) {
+        if (d->m_cursor.dirty || !cursorNode->texture()) {
             cursorNode->setTexture(window()->createTextureFromImage(d->m_cursor.texture));
             d->m_cursor.dirty = false;
         }
@@ -322,6 +328,9 @@ void PipeWireSourceItem::processFrame(const PipeWireFrame &frame)
             d->m_cursor.dirty = true;
             d->m_cursor.texture = frame.cursor->texture;
         }
+    } else {
+        d->m_cursor.position = std::nullopt;
+        d->m_cursor.hotspot = {};
     }
 
     if (frame.dmabuf) {
@@ -442,3 +451,11 @@ uint PipeWireSourceItem::nodeId() const
 {
     return d->m_nodeId;
 }
+
+QSize PipeWireSourceItem::streamSize() const
+{
+    if (!d->m_stream) {
+        return QSize();
+    }
+    return d->m_stream->size();
+}
